SystemOrganization addCategory: #ConfigurationOfPillar!

Object subclass: #ConfigurationOfPillar
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfPillar'!

!ConfigurationOfPillar commentStamp: '<historical>' prior: 0!
I describe Pillar's dependencies and versions.!

!ConfigurationOfPillar class methodsFor: 'development support' stamp: 'DamienCassou 10/7/2013 11:10'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 13:34'!
catalogChangeLog
	^ 'nothing'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 12:12'!
catalogContactInfo
	^ 'The original creator of Pillar (formerly known as ''''the syntax behind the Pier CMS'''') is Lukas Renggli. Nevertheless, *Damien Cassou>damien.cassou@gmail.com* is now the maintainer. The website is at *http://www.smalltalkhub.com/#!!/~Pier/Pillar*.'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 12:09'!
catalogDescription
	^ 'Pillar is a wiki-like syntax, its document model, a parser for it, and a set of exporters (e.g., HTML, LaTeX, Markdown...). Pillar is primarily used as the wiki syntax behind the *Pier CMS>http://piercms.com*. Pillar is also being used to write books: e.g., *the Enterprise Pharo book>https://ci.inria.fr/pharo-contribution/job/PharoForTheEnterprise/lastSuccessfulBuild/artifact*.'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 12:18'!
catalogKeyClassesAndExample
	^ 'The key classes are:

- ==PRDocumentItem== and all its subclasses (e.g., ==PRLink==, ==PRParagraph==, ==PRHeader==, ==PRDocument==). These classes represent the document model.
- ==PRDocumentParser== which takes a pillar-formatted string as input and produces a ==PRDocument== (i.e., the document model) as output. Its main public method is its ==parse:== method on class-side to start the parsing process.
- ==PRVisitor== which provides all the functionality to navigate the document model.
- ==PRDocumentWriter2== is the superclass of all classes supposed to output a pier document model to a text file. Its subclasses include one to output a LaTeX document and one to output an HTML webpage.

From Pharo, you can create an HTML out of a Pillar-formatted string by writing a code similar to:

[[[language=Smalltalk
PRHTMLWriter defaultConfigurations anyOne
    inputString: ''Some text with *a link to Pharo>http://www.pharo.org*.'';
    outputFile: ''myFirstPillarExport.html'' asFileReference;
    export
]]]

Executing this code will result in the creation of a ==myFirstPillarExport.html== file with this content:

[[[language=html
<p>Some text with <a href="http://www.pharo.org">a link to Pharo</a>.</p>
]]]
'! !

!ConfigurationOfPillar class methodsFor: 'metadata' stamp: 'DamienCassou 12/19/2013 11:41'!
catalogKeywords
	^ #(pier book wiki html latex markdown)! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfPillar class methodsFor: 'private' stamp: 'DamienCassou 10/7/2013 11:10'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfPillar class methodsFor: 'metacello tool support' stamp: 'DamienCassou 10/7/2013 11:10'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfPillar class methodsFor: 'loading' stamp: 'DamienCassou 10/7/2013 11:10'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfPillar class methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
project

	^self new project! !

!ConfigurationOfPillar class methodsFor: 'development support' stamp: 'DamienCassou 10/7/2013 11:10'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 11/28/2013 14:19'!
"protocol: accessing"
baseline01: spec
	<version: '0.1-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/'.
			spec package: 'Pillar-Model' with: [ spec requires: #('Grease') ].
			spec package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ].
			spec package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-Model') ].
			spec package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-Model') ].
			spec package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-Model' ].
			spec package: 'Pillar-Tests-ExporterLaTeX' with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-Model') ].
			spec package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-Model' ].
			spec package: 'Pillar-Tests-ExporterMarkdown' with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-Model') ].
			spec group: 'ALL' with: #('Pillar-Tests-ExporterLaTeX' 'Pillar-Tests-ExporterHTML' 'Pillar-Tests-ExporterMarkdown' ).
			self greaseDev: spec ]! !

!ConfigurationOfPillar methodsFor: 'baselines' stamp: 'DamienCassou 11/28/2013 15:14'!
baseline02: spec
	"protocol: accessing"

	<version: '0.2-baseline'>
	spec
		for: #common
		do: [ 
			spec
				blessing: #baseline;
				repository: 'http://smalltalkhub.com/mc/Pier/Pillar/main/';
				package: 'Pillar-Model' with: [ spec requires: #('Grease') ];
				package: 'Pillar-ExporterCore' with: [ spec requires: #('Pillar-Model' 'Mustache' 'STON') ];
				package: 'Pillar-Tests-Model' with: [ spec requires: #('Pillar-Model') ];
				package: 'Pillar-Tests-ExporterCore' with: [ spec requires: #('Pillar-Tests-Model' 'Pillar-ExporterCore') ];
				package: 'Pillar-ExporterHTML' with: [ spec requires: #('Pillar-ExporterCore') ];
				package: 'Pillar-Tests-ExporterHTML' with: [ spec requires: #('Pillar-ExporterHTML' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterLaTeX' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterLaTeX'
					with: [ spec requires: #('Pillar-ExporterLaTeX' 'Pillar-Tests-ExporterCore') ];
				package: 'Pillar-ExporterMarkdown' with: [ spec requires: 'Pillar-ExporterCore' ];
				package: 'Pillar-Tests-ExporterMarkdown'
					with: [ spec requires: #('Pillar-ExporterMarkdown' 'Pillar-Tests-ExporterCore') ].
			spec group: 'ALL' with: #('Pillar-Tests-ExporterLaTeX' 'Pillar-Tests-ExporterHTML' 'Pillar-Tests-ExporterMarkdown').
			self
				greaseDev: spec;
				mustacheStable: spec;
				stonStable: spec ]! !

!ConfigurationOfPillar methodsFor: 'symbolic versions' stamp: 'DamienCassou 11/28/2013 14:01'!
bleedingEdge: spec
	<symbolicVersion: #bleedingEdge>
	spec for: #common version: '0.2-baseline'! !

!ConfigurationOfPillar methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfPillar methodsFor: 'symbolic versions' stamp: 'DamienCassou 1/3/2014 23:32'!
development: spec
	<symbolicVersion: #development>
	spec for: #common version: '0.3'! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DamienCassou 11/28/2013 14:19'!
greaseDev: spec
	spec
		project: 'Grease'
		with: [ 
			spec
				className: 'ConfigurationOfGrease';
				versionString: #development;
				loads: #('Core');
				repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main' ]! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DamienCassou 11/28/2013 14:21'!
mustacheStable: spec
	spec
		project: 'Mustache'
		with: [ 
			spec
				className: 'ConfigurationOfMustache';
				versionString: #stable;
				loads: #('Core');
				repository: 'http://www.smalltalkhub.com/mc/NorbertHartl/Mustache/main' ]! !

!ConfigurationOfPillar methodsFor: 'accessing' stamp: 'DamienCassou 10/7/2013 11:10'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfPillar methodsFor: 'symbolic versions' stamp: 'DamienCassou 12/9/2013 17:25'!
stable: spec
	<symbolicVersion: #stable>
	spec for: #common version: '0.2'! !

!ConfigurationOfPillar methodsFor: 'dependencies' stamp: 'DamienCassou 11/29/2013 10:28'!
stonStable: spec
	spec
		project: 'STON'
		with: [ 
			spec
				className: 'ConfigurationOfSton';
				versionString: #stable;
				loads: #('Core');
				repository: 'http://smalltalkhub.com/mc/SvenVanCaekenberghe/STON/main' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 11/28/2013 13:58'!
version01: spec
	"protocol: accessing"

	<version: '0.1' imports: #('0.1-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.34';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.18';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.23';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.27';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.24';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.13';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.15';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.3' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 12/10/2013 10:19'!
version02: spec
	<version: '0.2' imports: #('0.2-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #release;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.37';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-DamienCassou.19';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.20';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.29';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.30';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.27';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.15';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.13';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.16';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.3' ]! !

!ConfigurationOfPillar methodsFor: 'versions' stamp: 'DamienCassou 1/3/2014 23:31'!
version03: spec
	<version: '0.3' imports: #('0.2-baseline')>
	spec
		for: #common
		do: [ 
			spec
				blessing: #development;
				package: 'Pillar-Model' with: 'Pillar-Model-DamienCassou.37';
				package: 'Pillar-ExporterCore' with: 'Pillar-ExporterCore-BenjaminVanRyseghem.35';
				package: 'Pillar-ExporterHTML' with: 'Pillar-ExporterHTML-DamienCassou.22';
				package: 'Pillar-ExporterLaTeX' with: 'Pillar-ExporterLaTeX-DamienCassou.30';
				package: 'Pillar-ExporterMarkdown' with: 'Pillar-ExporterMarkdown-DamienCassou.31';
				package: 'Pillar-Tests-Model' with: 'Pillar-Tests-Model-DamienCassou.27';
				package: 'Pillar-Tests-ExporterCore' with: 'Pillar-Tests-ExporterCore-DamienCassou.21';
				package: 'Pillar-Tests-ExporterHTML' with: 'Pillar-Tests-ExporterHTML-DamienCassou.13';
				package: 'Pillar-Tests-ExporterLaTeX' with: 'Pillar-Tests-ExporterLaTeX-DamienCassou.16';
				package: 'Pillar-Tests-ExporterMarkdown' with: 'Pillar-Tests-ExporterMarkdown-DamienCassou.3' ]! !
